@@ -28,5 +28,6 @@ test_that("RC names", {
   expect_equal(
     decode(500004, "sjukhus_rc", "sjukhus_rc_namn"), "Angereds N\u00E4rsjukhus")
   expect_equal(
-    decode(500004, "sjukhus_rc", "forvaltning_rc_namn"), "Angereds n\u00E4rsjukhus")
+    decode(500004, "sjukhus_rc", "forvaltning_rc_namn"), 
+    "Angereds n\u00E4rsjukhus")
 })
